@@ -253,12 +253,10 @@ for a specific error.
 
     'attr-repeated'            => ['${attr} attribute in <${tag}> is repeated', STRUCTURE],
     'attr-unknown'             => ['Unknown attribute "${attr}" for tag <${tag}>', FLUFF],
-    'attr-invalid-entity'      => ['Entity ${entity} is invalid', STRUCTURE],
     'attr-unclosed-entity'     => ['Entity ${entity} is missing its closing semicolon', STRUCTURE],
     'attr-unknown-entity'      => ['Entity ${entity} is unknown', STRUCTURE],
     'attr-use-entity'          => ['Character "${char}" should be written as ${entity}', STRUCTURE],
 
-    'text-invalid-entity'      => ['Entity ${entity} is invalid', STRUCTURE],
     'text-unclosed-entity'     => ['Entity ${entity} is missing its closing semicolon', STRUCTURE],
     'text-unknown-entity'      => ['Entity ${entity} is unknown', STRUCTURE],
     'text-use-entity'          => ['Character "${char}" should be written as ${entity}', STRUCTURE],
@@ -324,10 +322,6 @@ ATTR attribute in C<< <tag> >> is repeated.
 
 Unknown attribute "ATTR" for tag C<< <tag> >>.
 
-=head2 text-invalid-entity
-
-Entity ENTITY is invalid
-
 =head2 text-unclosed-entity
 
 Entity ENTITY is missing its closing semicolon
